@@ -9,17 +9,18 @@ from django.conf import settings
 
 os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'crm.settings')
 
-from dotenv import load_dotenv
-# explicitly providing path to '.env'
-from pathlib import Path  # python3 only
-env_path = Path('~') / '.crm'
-load_dotenv(dotenv_path=env_path)
+from dotenv import load_dotenv, find_dotenv
+from pathlib import Path
+dotenv_filename = '.crm'
+dotenv_path = find_dotenv(
+    filename=dotenv_filename,
+    raise_error_if_not_found=True,
+    usecwd=True
+)
+print('Load dotenv configuration from %s' % dotenv_path)
+load_dotenv(dotenv_path=dotenv_path)
 
-os.environ.setdefault("DJANGO_CONFIGURATION", os.getenv('KRYNEGGER_CONFIGURATION', 'Development').capitalize())
-
-
-# os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'crm.dev_settings')
-# os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'crm.server_settings')
+os.environ.setdefault("DJANGO_CONFIGURATION", os.getenv('KRYNEGGER_CONFIGURATION').capitalize())
 
 import configurations
 configurations.setup()
