@@ -9,21 +9,24 @@ if __name__ == "__main__":
     os.environ.setdefault("DJANGO_CONFIGURATION", 'Development')
 
     try:
-        import os
-        from dotenv import load_dotenv
-        # explicitly providing path to '.env'
-        from pathlib import Path  # python3 only
-        env_path = Path('.') / '.crm'
-        load_dotenv(dotenv_path=env_path)
+        from dotenv import load_dotenv, find_dotenv
+        from pathlib import Path
 
+        dotenv_filename = '.crm'
+        dotenv_path = find_dotenv(
+            filename=dotenv_filename,
+            raise_error_if_not_found=True,
+            usecwd=True
+        )
+        print('Load dotenv configuration from %s' % dotenv_path)
+        load_dotenv(dotenv_path=dotenv_path)
+
+        os.environ.setdefault("DJANGO_CONFIGURATION", os.getenv('KRYNEGGER_CONFIGURATION').capitalize())
     except BaseException as e:
         logging.error('Dotenv file could not loaded')
         # logging.exception(e)
         # traceback.print_exc()
 
-    finally:
-        ENVIRONMENT_CONFIGURATION = os.getenv("DJANGO_CONFIGURATION", 'Development')
-
     try:
         from configurations.management import execute_from_command_line
     except ImportError:
